aboutsummaryrefslogtreecommitdiffstats
path: root/xd_view.c
diff options
context:
space:
mode:
Diffstat (limited to 'xd_view.c')
-rw-r--r--xd_view.c8
1 files changed, 4 insertions, 4 deletions
diff --git a/xd_view.c b/xd_view.c
index 38e4349..3181c1f 100644
--- a/xd_view.c
+++ b/xd_view.c
@@ -191,12 +191,12 @@ static void open_tty(gint id, char *name, char *tty, int screen)
static void open_vnc(gint id, char *name, char *ostype)
{
- if (0 == strcmp(ostype, "vmx")) {
- /* works for vmx ... */
+ if (0 == strcmp(ostype, "hvm")) {
+ /* works for hvm ... */
if (-1 == open_vnc_session("localhost", id))
gtk_message(GTK_MESSAGE_ERROR, app_error);
} else {
- gtk_message(GTK_MESSAGE_ERROR, "VNC works for vmx domains only.\n");
+ gtk_message(GTK_MESSAGE_ERROR, "VNC works for hvm domains only.\n");
}
}
@@ -444,7 +444,7 @@ static const GtkActionEntry entries[] = {
.name = "OpenVNC",
.label = "_VNC",
.accelerator = "<control>V",
- .tooltip = "Open VNC viewer (vmx domains only)",
+ .tooltip = "Open VNC viewer (hvm domains only)",
.callback = menu_cb_open_vnc,
},{
.name = "OpenConsole",